@@ -5,7 +5,6 @@ import inspect
 import os
 import platform
 import shutil
-import subprocess
 import sys
 from abc import ABC, abstractmethod
 from cgi import parse_header
@@ -25,6 +24,7 @@ from briefcase.exceptions import (
     BriefcaseConfigError,
     MissingNetworkResourceError
 )
+from briefcase.integrations.subprocess import Subprocess
 
 
 class TemplateUnsupportedVersion(BriefcaseCommandError):
@@ -79,22 +79,22 @@ def cookiecutter_cache_path(template):
     return Path.home() / '.cookiecutters' / cache_name
 
 
-def full_kwargs(state, kwargs):
+def full_options(state, options):
     """
     Merge command state with keyword arguments.
 
     Command state takes precedence over any keyword argument.
 
     :param state: The current command state. Can be ``None``.
-    :param kwargs: The base keyword arguments.
-    :returns: A dictionary containing all of ``kwargs``, with any values
-        provided in ``state`` overriding the base ``kwargs`` values.
+    :param options: The base options.
+    :returns: A dictionary containing all of ``options``, with any values
+        provided in ``state`` overriding the base ``options`` values.
     """
     if state is not None:
-        full = kwargs.copy()
+        full = options.copy()
         full.update(state)
     else:
-        full = kwargs
+        full = options
 
     return full
 
@@ -124,7 +124,7 @@ class BaseCommand(ABC):
         self.os = os
         self.sys = sys
         self.shutil = shutil
-        self.subprocess = subprocess
+        self.subprocess = Subprocess(self)
 
         # The internal Briefcase integrations API.
         self.integrations = integrations
@@ -133,61 +133,73 @@ class BaseCommand(ABC):
     def create_command(self):
         "Factory property; return an instance of a create command for the same format"
         format_module = importlib.import_module(self.__module__)
-        return format_module.create(
+        command = format_module.create(
             base_path=self.base_path,
             apps=self.apps,
             input_enabled=self.input.enabled,
         )
+        command.clone_options(self)
+        return command
 
     @property
     def update_command(self):
         "Factory property; return an instance of an update command for the same format"
         format_module = importlib.import_module(self.__module__)
-        return format_module.update(
+        command = format_module.update(
             base_path=self.base_path,
             apps=self.apps,
             input_enabled=self.input.enabled,
         )
+        command.clone_options(self)
+        return command
 
     @property
     def build_command(self):
         "Factory property; return an instance of a build command for the same format"
         format_module = importlib.import_module(self.__module__)
-        return format_module.build(
+        command = format_module.build(
             base_path=self.base_path,
             apps=self.apps,
             input_enabled=self.input.enabled,
         )
+        command.clone_options(self)
+        return command
 
     @property
     def run_command(self):
         "Factory property; return an instance of a run command for the same format"
         format_module = importlib.import_module(self.__module__)
-        return format_module.run(
+        command = format_module.run(
             base_path=self.base_path,
             apps=self.apps,
             input_enabled=self.input.enabled,
         )
+        command.clone_options(self)
+        return command
 
     @property
     def package_command(self):
         "Factory property; return an instance of a package command for the same format"
         format_module = importlib.import_module(self.__module__)
-        return format_module.package(
+        command = format_module.package(
             base_path=self.base_path,
             apps=self.apps,
             input_enabled=self.input.enabled,
         )
+        command.clone_options(self)
+        return command
 
     @property
     def publish_command(self):
         "Factory property; return an instance of a publish command for the same format"
         format_module = importlib.import_module(self.__module__)
-        return format_module.publish(
+        command = format_module.publish(
             base_path=self.base_path,
             apps=self.apps,
             input_enabled=self.input.enabled,
         )
+        command.clone_options(self)
+        return command
 
     @property
     def platform_path(self):
@@ -300,7 +312,22 @@ class BaseCommand(ABC):
         # Parse the full set of command line options from the content
         # remaining after the basic command/platform/output format
         # has been extracted.
-        return vars(parser.parse_args(extra))
+        options = vars(parser.parse_args(extra))
+
+        # Extract the base default options onto the command
+        self.input.enabled = options.pop('input_enabled')
+        self.verbosity = options.pop('verbosity')
+
+        return options
+
+    def clone_options(self, command):
+        """
+        Clone options from one command to this one.
+
+        :param command: The command whose options are to be cloned
+        """
+        self.input.enabled = command.input.enabled
+        self.verbosity = command.verbosity
 
     def add_default_options(self, parser):
         """
