@@ -14,7 +14,7 @@ class DeviceState(enum.Enum):
     UNKNOWN = 99
 
 
-def verify_command_line_tools_install(sub=subprocess):
+def verify_command_line_tools_install(command):
     """Verify that command line developer tools are installed and ready for use.
 
     A completely clean machine will have neither Xcode *or* the Command Line
@@ -23,14 +23,13 @@ def verify_command_line_tools_install(sub=subprocess):
 
     Lastly, there is a license that needs to be accepted.
 
-    :param sub: the module for starting subprocesses. Defaults to
-        Python's builtin; used for testing purposes.
+    :param command: The command that needs to perform the verification check.
     """
-    ensure_command_line_tools_are_installed(sub=sub)
-    confirm_xcode_license_accepted(sub=sub)
+    ensure_command_line_tools_are_installed(command)
+    confirm_xcode_license_accepted(command)
 
 
-def verify_xcode_install(min_version=None, sub=subprocess):
+def verify_xcode_install(command, min_version=None):
     """Verify that Xcode and the command line developer tools are installed and
     ready for use.
 
@@ -45,29 +44,27 @@ def verify_xcode_install(min_version=None, sub=subprocess):
 
     Lastly, we ensure that the iOS simulator is installed.
 
+    :param command: The command that needs to perform the verification check.
     :param min_version: The minimum allowed version of Xcode, specified as a
         tuple of integers (e.g., (11, 2, 1)). Default: ``None``, meaning there
         is no minimum version.
-    :param sub: the module for starting subprocesses. Defaults to
-        Python's builtin; used for testing purposes.
     """
-    ensure_xcode_is_installed(min_version=min_version, sub=sub)
-    ensure_command_line_tools_are_installed(sub=sub)
-    confirm_xcode_license_accepted(sub=sub)
+    ensure_xcode_is_installed(command, min_version=min_version)
+    ensure_command_line_tools_are_installed(command)
+    confirm_xcode_license_accepted(command)
 
 
-def ensure_command_line_tools_are_installed(sub=subprocess):
+def ensure_command_line_tools_are_installed(command):
     """
     Determine if the Xcode command line tools are installed.
 
     If they are not installed, an exception is raised; in addition, a OS dialog
     will be displayed prompting the user to install Xcode.
 
+    :param command: The command that needs to perform the verification check.
     :param min_version: The minimum allowed version of Xcode, specified as a
         tuple of integers (e.g., (11, 2, 1)). Default: ``None``, meaning there
         is no minimum version.
-    :param sub: the module for starting subprocesses. Defaults to
-        Python's builtin; used for testing purposes.
     """
     # We determine if the command line tools are installed by running:
     #
@@ -81,7 +78,7 @@ def ensure_command_line_tools_are_installed(sub=subprocess):
     #
     # Any other status code is a problem.
     try:
-        sub.check_output(
+        command.subprocess.check_output(
             ['xcode-select', '--install'],
             stderr=subprocess.STDOUT
         )
@@ -101,9 +98,8 @@ Re-run Briefcase once that installation is complete.
 ** WARNING: Unable to determine if Xcode is installed                  **
 *************************************************************************
 
-   Briefcase will proceed assume everything is OK, but if you
-   experience problems, this is almost certainly the cause of those
-   problems.
+   Briefcase will proceed, assuming everything is OK. If you experience
+   problems, this is almost certainly the cause of those problems.
 
    Please report this as a bug at:
 
@@ -120,9 +116,9 @@ Re-run Briefcase once that installation is complete.
 
 
 def ensure_xcode_is_installed(
+    command,
     xcode_location='/Applications/Xcode.app',
     min_version=None,
-    sub=subprocess
 ):
     """
     Determine if Xcode is installed; and if so, that it meets minimum version
@@ -131,14 +127,13 @@ def ensure_xcode_is_installed(
     Raises an exception if XCode isn't installed, or if the version of Xcode
     that is installed doesn't meet the minimum requirement.
 
+    :param command: The command that needs to perform the verification check.
     :param xcode_location: The location where Xcode should be installed.
         Default is `/Applications/Xcode.app`, which is where the App Store
         installs Xcode.
     :param min_version: The minimum allowed version of Xcode, specified as a
         tuple of integers (e.g., (11, 2, 1)). Default: ``None``, meaning there
         is no minimum version.
-    :param sub: the module for starting subprocesses. Defaults to
-        Python's builtin; used for testing purposes.
     """
     # Try the direct approach. Look for the Xcode folder that is created
     # when you install from the App store.
@@ -151,8 +146,9 @@ You can install Xcode from the macOS App Store.
 Re-run Briefcase once that installation is complete.
 """)
     try:
-        output = sub.check_output(
+        output = command.subprocess.check_output(
             ['xcodebuild', '-version'],
+            stderr=subprocess.STDOUT,
             universal_newlines=True
         )
 
@@ -187,9 +183,8 @@ Re-run Briefcase once that installation is complete.
 ** WARNING: Unable to determine the version of Xcode that is installed **
 *************************************************************************
 
-   Briefcase will proceed assume everything is OK, but if you
-   experience problems, this is almost certainly the cause of those
-   problems.
+   Briefcase will proceed, assuming everything is OK. If you experience
+   problems, this is almost certainly the cause of those problems.
 
    Please report this as a bug at:
 
@@ -202,28 +197,44 @@ Re-run Briefcase once that installation is complete.
    from the command prompt.
 
 *************************************************************************
-
 """)
 
-    except subprocess.CalledProcessError:
-        raise BriefcaseCommandError("""
-Xcode is not installed.
+    except subprocess.CalledProcessError as e:
+        if " is a command line tools instance" in e.output:
+            raise BriefcaseCommandError("""
+Xcode is installed, but the active developer directory is a
+command line tools instance. To make XCode the active developer
+directory, run:
 
-You should be shown a dialog prompting you to install Xcode and the
-command line tools. Select "Get Xcode" to install Xcode from the app store.
+    $ sudo xcode-select -switch /Applications/Xcode.app
 
-You can install Xcode from the macOS App Store.
+and then re-run Briefcase.
+""")
+        else:
+            raise BriefcaseCommandError("""
+The Xcode install appears to exist, but Briefcase was unable to
+determine the current Xcode version. Running:
 
-Re-run Briefcase once that installation is complete.
+    $ xcodebuild -version
+
+should return the current Xcode version, but it raised an error.
+
+You may need to re-install Xcode. Re-run Briefcase once that
+installation is complete.
 """)
 
 
-def confirm_xcode_license_accepted(sub=subprocess):
+def confirm_xcode_license_accepted(command):
+    """
+    Confirm if the Xcode license has been accepted.
+
+    :param command: The command that needs to perform the verification check.
+    """
     # Lastly, check if the XCode license has been accepted. The command line
     # tools return a status code of 69 (nice...) if the license has not been
     # accepted. In this case, we can prompt the user to accept the license.
     try:
-        sub.check_output(
+        command.subprocess.check_output(
             ['/usr/bin/clang', '--version'],
             stderr=subprocess.STDOUT
         )
@@ -244,7 +255,7 @@ Briefcase will try the command line version of this command now. You will need
 to enter your password (Briefcase will not store this password anywhere).
 """)
             try:
-                sub.run(
+                command.subprocess.run(
                     ['sudo', 'xcodebuild', '-license'],
                     check=True,
                 )
@@ -271,9 +282,8 @@ You need to accept the Xcode license before Briefcase can package your app.
 ** WARNING: Unable to determine if the Xcode license has been accepted **
 *************************************************************************
 
-   Briefcase will proceed assume everything is OK, but if you
-   experience problems, this is almost certainly the cause of those
-   problems.
+   Briefcase will proceed, assuming everything is OK. If you experience
+   problems, this is almost certainly the cause of those problems.
 
    Please report this as a bug at:
 
@@ -286,7 +296,6 @@ You need to accept the Xcode license before Briefcase can package your app.
    from the command prompt.
 
 *************************************************************************
-
 """)
         else:
             print("""
@@ -294,9 +303,8 @@ You need to accept the Xcode license before Briefcase can package your app.
 ** WARNING: Unable to determine if the Xcode license has been accepted **
 *************************************************************************
 
-   Briefcase will proceed assume everything is OK, but if you
-   experience problems, this is almost certainly the cause of those
-   problems.
+   Briefcase will proceed, assuming everything is OK. If you experience
+   problems, this is almost certainly the cause of those problems.
 
    Please report this as a bug at:
 
@@ -309,15 +317,13 @@ You need to accept the Xcode license before Briefcase can package your app.
    from the command prompt.
 
 *************************************************************************
-
 """)
 
 
 def get_simulators(
+    command,
     os_name,
     simulator_location='/Library/Developer/PrivateFrameworks/CoreSimulator.framework/',
-    sub=subprocess,
-    prompt=input,
 ):
     """
     Obtain the simulators available on this machine.
@@ -326,19 +332,18 @@ def get_simulators(
     keyed by OS version; the inner dictionary for each OS version
     contains the details of the available simulators, keyed by UDID.
 
+    :param command: The command that needs to know the list of available
+        simulators.
     :param os_name: The OS that we want to simulate.
         One of `"iOS"`, `"watchOS"`, or `"tvOS"`.
     :param simulator_location: The filesystem path where the simulator
         frameworks are installed.
-    :param sub: the module for starting subprocesses. Defaults to
-        Python's builtin; used for testing purposes.
-    :param prompt: the method to use to prompt the user.
     :returns: A dictionary of available simulators.
     """
     # If the simulator frameworks don't exist, they will be downloaded
     # and installed. This should only occur on first execution.
     if not Path(simulator_location).exists():
-        prompt("""
+        command.input("""
 It looks like the {os_name} Simulator is not installed. The {os_name} Simulator
 must be installed with administrator priviliges.
 
@@ -349,7 +354,7 @@ Press Return to continue: """.format(os_name=os_name))
 
     try:
         simctl_data = json.loads(
-            sub.check_output(
+            command.subprocess.check_output(
                 ['xcrun', 'simctl', 'list', '-j'],
                 universal_newlines=True
             )
@@ -398,18 +403,17 @@ Press Return to continue: """.format(os_name=os_name))
         )
 
 
-def get_device_state(udid, sub=subprocess):
+def get_device_state(command, udid):
     """
     Determine the state of an iOS simulator device.
 
+    :param command: The command that needs to know the simulator device state.
     :param udid: The UDID of the device to inspect
-    :param sub: the module for starting subprocesses. Defaults to
-        Python's builtin; used for testing purposes.
     :returns: The status of the device, as a DeviceState enum.
     """
     try:
         simctl_data = json.loads(
-            sub.check_output(
+            command.subprocess.check_output(
                 ['xcrun', 'simctl', 'list', 'devices', '-j', udid],
                 universal_newlines=True
             )
@@ -441,14 +445,15 @@ def get_device_state(udid, sub=subprocess):
 IDENTITY_RE = re.compile(r'\s*\d+\) ([0-9A-F]{40}) \"(.*)\"')
 
 
-def get_identities(policy, sub=subprocess):
+def get_identities(command, policy):
     """
     Obtain a set of valid identities for the given policy
 
+    :param command: The command that needs the identities.
     :param policy: The identity policy to evaluate (e.g., ``codesigning``)
     """
     try:
-        output = sub.check_output(
+        output = command.subprocess.check_output(
             ['security', 'find-identity', '-v', '-p', policy],
             universal_newlines=True
         )
