@@ -13,9 +13,8 @@ class macOSMixin:
 macOS applications require the Xcode command line tools, which are
 only available on macOS.
 """)
-
         # Require the XCode command line tools.
-        verify_command_line_tools_install()
+        verify_command_line_tools_install(self)
 
         # Verify superclass tools *after* xcode. This ensures we get the
         # git check *after* the xcode check.
