@@ -62,9 +62,9 @@ class TrackingCreateCommand(DummyCreateCommand):
 
         self.actions = []
 
-    def verify_tools(self):
+    def verify_tools(self,):
         super().verify_tools()
-        self.actions.append(('verify'))
+        self.actions.append(('verify',))
 
     # Override all the body methods of a CreateCommand
     # with versions that we can use to track actions performed.
