@@ -91,7 +91,9 @@ def test_new_command():
     assert isinstance(cmd, NewCommand)
     assert cmd.platform == 'all'
     assert cmd.output_format is None
-    assert options == {'input_enabled': True, 'template': None, 'verbosity': 1}
+    assert cmd.input.enabled
+    assert cmd.verbosity == 1
+    assert options == {'template': None}
 
 
 def test_dev_command(monkeypatch):
@@ -104,9 +106,9 @@ def test_dev_command(monkeypatch):
     assert isinstance(cmd, DevCommand)
     assert cmd.platform == 'macOS'
     assert cmd.output_format is None
+    assert cmd.input.enabled
+    assert cmd.verbosity == 1
     assert options == {
-        'input_enabled': True,
-        'verbosity': 1,
         'appname': None,
         'update_dependencies': False
     }
@@ -122,7 +124,9 @@ def test_bare_command(monkeypatch):
     assert isinstance(cmd, macOSAppCreateCommand)
     assert cmd.platform == 'macOS'
     assert cmd.output_format == 'dmg'
-    assert options == {'input_enabled': True, 'verbosity': 1}
+    assert cmd.input.enabled
+    assert cmd.verbosity == 1
+    assert options == {}
 
 
 @pytest.mark.skipif(sys.platform != 'linux', reason="requires Linux")
@@ -134,7 +138,9 @@ def test_linux_default():
     assert isinstance(cmd, LinuxAppImageCreateCommand)
     assert cmd.platform == 'linux'
     assert cmd.output_format == 'appimage'
-    assert options == {'input_enabled': True, 'verbosity': 1}
+    assert cmd.input.enabled
+    assert cmd.verbosity == 1
+    assert options == {}
 
 
 @pytest.mark.skipif(sys.platform != 'darwin', reason="requires macOS")
@@ -146,7 +152,9 @@ def test_macOS_default():
     assert isinstance(cmd, macOSAppCreateCommand)
     assert cmd.platform == 'macOS'
     assert cmd.output_format == 'dmg'
-    assert options == {'input_enabled': True, 'verbosity': 1}
+    assert cmd.input.enabled
+    assert cmd.verbosity == 1
+    assert options == {}
 
 
 @pytest.mark.skipif(sys.platform != 'win32', reason="requires Windows")
@@ -158,7 +166,9 @@ def test_windows_default():
     assert isinstance(cmd, WindowsMSICreateCommand)
     assert cmd.platform == 'windows'
     assert cmd.output_format == 'msi'
-    assert options == {'input_enabled': True, 'verbosity': 1}
+    assert cmd.input.enabled
+    assert cmd.verbosity == 1
+    assert options == {}
 
 
 def test_bare_command_help(monkeypatch, capsys):
@@ -230,7 +240,9 @@ def test_command_explicit_platform(monkeypatch):
     assert isinstance(cmd, LinuxAppImageCreateCommand)
     assert cmd.platform == 'linux'
     assert cmd.output_format == 'appimage'
-    assert options == {'input_enabled': True, 'verbosity': 1}
+    assert cmd.input.enabled
+    assert cmd.verbosity == 1
+    assert options == {}
 
 
 def test_command_explicit_platform_case_handling(monkeypatch):
@@ -244,7 +256,9 @@ def test_command_explicit_platform_case_handling(monkeypatch):
     assert isinstance(cmd, macOSAppCreateCommand)
     assert cmd.platform == 'macOS'
     assert cmd.output_format == 'dmg'
-    assert options == {'input_enabled': True, 'verbosity': 1}
+    assert cmd.input.enabled
+    assert cmd.verbosity == 1
+    assert options == {}
 
 
 def test_command_explicit_platform_help(monkeypatch, capsys):
@@ -291,7 +305,9 @@ def test_command_explicit_format(monkeypatch):
     assert isinstance(cmd, macOSDmgCreateCommand)
     assert cmd.platform == 'macOS'
     assert cmd.output_format == 'dmg'
-    assert options == {'input_enabled': True, 'verbosity': 1}
+    assert cmd.input.enabled
+    assert cmd.verbosity == 1
+    assert options == {}
 
 
 def test_command_unknown_format(monkeypatch):
@@ -356,7 +372,9 @@ def test_command_disable_input(monkeypatch):
     assert isinstance(cmd, macOSAppCreateCommand)
     assert cmd.platform == 'macOS'
     assert cmd.output_format == 'dmg'
-    assert options == {'input_enabled': False, 'verbosity': 1}
+    assert not cmd.input.enabled
+    assert cmd.verbosity == 1
+    assert options == {}
 
 
 def test_command_options(monkeypatch, capsys):
@@ -369,9 +387,9 @@ def test_command_options(monkeypatch, capsys):
     cmd, options = parse_cmdline('publish macos app -c s3'.split())
 
     assert isinstance(cmd, macOSAppPublishCommand)
+    assert cmd.input.enabled
+    assert cmd.verbosity == 1
     assert options == {
-        'input_enabled': True,
-        'verbosity': 1,
         'channel': 's3'
     }
 
